/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Application
    membraneFoam

Description
    Solver for membrane modeling, membrane type is generic.
\*---------------------------------------------------------------------------*/

#include "fvCFD.H"
#include "rhoThermo.H"
#include "rhoCombustionModel.H"
#include "turbulentFluidThermoModel.H"
#include "multivariateScheme.H"
#include "fixedGradientFvPatchFields.H"
#include "regionProperties.H"
#include "compressibleCourantNo.H"
#include "radiationModel.H"
#include "fvOptions.H"
#include "localEulerDdtScheme.H"
#include "fvcSmooth.H"
#include "coordinateSystem.H"
#include "membraneModel.H"
#include "diffusionModel.H"

#include "mappedPatchBase.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

int main(int argc, char *argv[])
{
    #define NO_CONTROL
    #define CREATE_MESH createMeshesPostProcess.H
    #include "postProcess.H"
    #include "setRootCase.H"
    #include "createTime.H"

    regionProperties rp(runTime);

    #include "createMeshes.H"
    #include "createFields.H"  
    #include "initContinuityErrs.H"
    #include "createTimeControls.H"
    #include "createRDeltaT.H"
    #include "readTimeControls.H"

    if (!LTS)
    {
        #include "compressibleMultiRegionCourantNo.H"
        #include "setInitialMultiRegionDeltaT.H"
    }

    while (runTime.run())
    {
        #include "readTimeControls.H"
        #include "readPIMPLEControls.H"

        if (LTS)
        {
            #include "setRDeltaT.H"
        }
        else
        {
            #include "compressibleMultiRegionCourantNo.H"
            #include "setMultiRegionDeltaT.H"
        }

        runTime++;

        Info<< "Time = " << runTime.timeName() << nl << endl;

        #include "membrane.H"
        
        forAll(regions, i)
        {
            #include "storeOldFields.H"
        }

        // --- PIMPLE loop
        for (int oCorr=0; oCorr<nOuterCorr; oCorr++)
        {
            bool finalIter = oCorr == nOuterCorr-1;

            forAll(regions, i)
            {
                Info<< "\nSolving for region "
                    << regions[i].name() << endl;
                #include "setRegionFields.H"
                #include "readMultiRegionPIMPLEControls.H"
                #include "solveFluid.H" 
            }
        }        

        runTime.write();

        if(LTS)
        {
            #include "convergencyCheck.H"
        }
        
        Info<< "ExecutionTime = " << runTime.elapsedCpuTime() << " s"
            << "  ClockTime = " << runTime.elapsedClockTime() << " s"
            << nl << endl;
    }

    Info<< "End\n" << endl;

    return 0;
}

// ************************************************************************* //
