/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "polynomial.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace activityModels
{

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

defineTypeNameAndDebug(polynomial, 0);
addToRunTimeSelectionTable(activityModel, polynomial, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

polynomial::polynomial
(
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const word& modelName
)
:
    activityModel(modelName, mesh, chemistry),
    mesh_(mesh),
    chemistry_(chemistry)
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

volScalarField polynomial::activityCoeff(const word& specie)
{
    dictionary thermoDict_
    (
        IFstream
        (
            fileName(chemistry_.thermo().lookup("foamChemistryThermoFile")).expand()
        )()
    );

    Polynomial<8> activityTempCoeffs_
    (
        thermoDict_.subDict(specie)
        .subDict("activity").lookup("activityTempCoeffs<" + Foam::name(8) + '>')
    );
    
    volScalarField activityCoeffField_
    (
        IOobject
        (
            "activityCoeff",
            mesh_
        ),
        mesh_,
        dimensionedScalar("activityCoeff", dimless, 1.0)
    );

    forAll(activityCoeffField_, celli)
    {
        activityCoeffField_[celli] = activityTempCoeffs_.value(chemistry_.thermo().T()[celli]);
    }

    forAll(activityCoeffField_.boundaryField(), patchi)
    {
        forAll(activityCoeffField_.boundaryFieldRef()[patchi], facei)
        {
            activityCoeffField_.boundaryFieldRef()[patchi][facei] 
           = 
            activityTempCoeffs_.value(chemistry_.thermo().T().boundaryField()[patchi][facei]);
        }
    }

    return activityCoeffField_;
}


bool polynomial::read()
{
    return true;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace activityModels
} // End namespace Foam

// ************************************************************************* //
