/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::activityModels::polynomial

Description
    Returns a polynomial value for activity coefficients as a function 
    of temperature

    References:
    \verbatim

    \endverbatim

    Sample dictionary:
    \verbatim
        activity
        {
            activityTempCoeffs<8>   (1 0 0 0 0 0 0 0);
        }
    \endverbatim

SourceFiles
    polynomial.C

\*---------------------------------------------------------------------------*/

#ifndef polynomial_H
#define polynomial_H

#include "activityModel.H"
#include "Polynomial.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace activityModels
{

/*---------------------------------------------------------------------------*\
                           Class polynomial Declaration
\*---------------------------------------------------------------------------*/

class polynomial
:
    public activityModel
{

protected:

    const fvMesh& mesh_;
    const combustionModels::rhoCombustionModel& chemistry_;

    
public:

    //- Runtime type information
    TypeName("polynomial");

    // Constructors

        //- Construct from components
        polynomial
        (
            const fvMesh& mesh,
            const combustionModels::rhoCombustionModel& chemistry,
            const word& modelName = typeName
        );


    //- Destructor
    virtual ~polynomial()
    {}


    // Member Functions

        //- Return the activity coefficient per specie 
        virtual volScalarField activityCoeff(const word& specie);

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace activityModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
