/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "constant.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diffusionModels
{

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

defineTypeNameAndDebug(constant, 0);
addToRunTimeSelectionTable(diffusionModel, constant, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

constant::constant
(
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const compressible::turbulenceModel& turbulence,
    const word& modelName
)
:
    diffusionModel(modelName, mesh, chemistry, turbulence),
    mesh_(mesh),
    chemistry_(chemistry),
    turbulence_(turbulence)
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

volScalarField constant::effDiff(const word& specie)
{
    dictionary thermoDict_
    (
        IFstream
        (
            fileName(chemistry_.thermo().lookup("foamChemistryThermoFile")).expand()
        )()
    );

    scalar diffCoeff_
    (
        readScalar
        (
            thermoDict_.subDict(specie)
            .subDict("diffusion").lookup("diffCoeff")
        )
    );

    dimensionedScalar diffCoeffDim_
                      (
                        "diffCoeff", 
                        dimensionSet( 0, 2, -1, 0, 0, 0, 0), 
                        diffCoeff_
                      );

    return turbulence_.mut() + diffCoeffDim_ * chemistry_.thermo().rho();
}


bool constant::read()
{
    return true;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace diffusionModels
} // End namespace Foam

// ************************************************************************* //
