/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::diffusionModels::constant

Description
    Returns a constant value for diffusion coefficients

    References:
    \verbatim

    \endverbatim

    Sample dictionary:
    \verbatim
    diffusion
    {
        diffCoeff       8.9e-5; //[ 0 2 -1 0 0 0 0]
    }
    \endverbatim

SourceFiles
    constant.C

\*---------------------------------------------------------------------------*/

#ifndef constant_H
#define constant_H

#include "diffusionModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diffusionModels
{

/*---------------------------------------------------------------------------*\
                           Class constant Declaration
\*---------------------------------------------------------------------------*/

class constant
:
    public diffusionModel
{

protected:

    const fvMesh& mesh_;
    const combustionModels::rhoCombustionModel& chemistry_;
    const compressible::turbulenceModel& turbulence_;

    
public:

    //- Runtime type information
    TypeName("constant");

    // Constructors

        //- Construct from components
        constant
        (
            const fvMesh& mesh,
            const combustionModels::rhoCombustionModel& chemistry,
            const compressible::turbulenceModel& turbulence,
            const word& modelName = typeName
        );


    //- Destructor
    virtual ~constant()
    {}


    // Member Functions

        //- Return the effective diffusion coefficient per specie 
        virtual volScalarField effDiff(const word& specie);

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace diffusionModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
