/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "diffusionModel.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

defineTypeNameAndDebug(diffusionModel, 0);
defineRunTimeSelectionTable(diffusionModel, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

diffusionModel::diffusionModel
(
    const word& type,
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const compressible::turbulenceModel& turbulence
)
:
    mesh_(mesh),
    chemistry_(chemistry),
    turbulence_(turbulence)
{}


// * * * * * * * * * * * * * * * * * Selectors * * * * * * * * * * * * * * * //

autoPtr<diffusionModel> diffusionModel::New
(
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const compressible::turbulenceModel& turbulence
)
{
    const word modelType
    (
        IOdictionary
        (
            IOobject
            (
                "thermophysicalProperties",
                mesh.time().constant(),
                mesh,
                IOobject::MUST_READ_IF_MODIFIED,
                IOobject::NO_WRITE,
                false
            )
        ).subDict("thermoType").lookup("diffusionModel")
    );    

    Info << "Selecting diffusion model " << modelType << nl << endl;

    subModelConstructorTable::iterator cstrIter =
        subModelConstructorTablePtr_->find(modelType);

    if (cstrIter == subModelConstructorTablePtr_->end())
    {
        FatalErrorInFunction
            << "Unknown diffusion model type "
            << modelType << nl << nl
            << "Valid diffusion model types:" << endl
            << subModelConstructorTablePtr_->sortedToc()
            << exit(FatalError);
    }

    return autoPtr<diffusionModel>
    (
        cstrIter()(mesh, chemistry, turbulence)
    );
}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //


bool diffusionModel::read()
{
    return true;
}


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// ************************************************************************* //
