/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::diffusionModels::schmidtAnalogy

Description
    Returns diffusion coefficients based on Schmidt number analogy between
    flow and mass transfer

    References:
    \verbatim

    \endverbatim

    Sample dictionary:
    \verbatim

    \endverbatim

SourceFiles
    schmidtAnalogy.C

\*---------------------------------------------------------------------------*/

#ifndef schmidtAnalogy_H
#define schmidtAnalogy_H

#include "diffusionModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diffusionModels
{

/*---------------------------------------------------------------------------*\
                           Class schmidtAnalogy Declaration
\*---------------------------------------------------------------------------*/

class schmidtAnalogy
:
    public diffusionModel
{

protected:

    const fvMesh& mesh_;
    const combustionModels::rhoCombustionModel& chemistry_;
    const compressible::turbulenceModel& turbulence_;

    
public:

    //- Runtime type information
    TypeName("schmidtAnalogy");

    // Constructors

        //- Construct from components
        schmidtAnalogy
        (
            const fvMesh& mesh,
            const combustionModels::rhoCombustionModel& chemistry,
            const compressible::turbulenceModel& turbulence,
            const word& modelName = typeName
        );


    //- Destructor
    virtual ~schmidtAnalogy()
    {}


    // Member Functions

        //- Return the effective diffusion coefficient per specie 
        virtual volScalarField effDiff(const word& specie);

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace diffusionModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
