/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::membraneIO

Description
    The class for reading data from membrane dictionary

SourceFiles
    membraneIO.C

\*---------------------------------------------------------------------------*/

#ifndef membraneIO_H
#define membraneIO_H

#include "scalar.H"
#include "IOdictionary.H"
#include "typeInfo.H"
#include "volFields.H"
#include "dimensionedScalar.H"
#include "Pair.H"
#include "autoPtr.H"
#include "mappedPatchBase.H"
#include "Polynomial.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                     Class membraneIO Declaration
\*---------------------------------------------------------------------------*/

class membraneIO
{

protected:

    // Protected data
    const fvMesh& mesh_;
    const word patchName_;

public:

    //- Runtime type information
    TypeName("membraneIO");

    // Constructors

        //- Construct from mesh and patch name
        membraneIO(const fvMesh&, const word&);


    //- Destructor
    virtual ~membraneIO()
    {}


    // Member functions

        //- Return membrane sub-dictionary from both regions
        virtual Pair<dictionary> patchDicts();

        //- Return sub-sub-dictionary from both regions
        virtual Pair<dictionary> subDicts(const Pair<dictionary>&, const word subDictName);

        //- Read and return the value for a scalar
        virtual scalar readScalar(const Pair<dictionary>& subdicts, const word prop);

        //- Read and return the value for a word
        virtual word readWord(const Pair<dictionary>& subdicts, const word prop);

        //- Read and return the values for a word list
        virtual wordList readWordList(const Pair<dictionary>& subdicts, const word prop);

        //- Read and return the values for a polynomial coeffs
        virtual Polynomial<8> readPolynom(const Pair<dictionary>& subdicts, const word prop);

        //- Error in case of reading a dictionary
        virtual void readDictError(const Pair<dictionary>& subdicts, const word prop);

        //- Error in case of reading a dictionary
        virtual void inconsitentValueError(const Pair<dictionary>& subdicts, const word prop);

        //- Return my region membrane dictionary
        virtual dictionary ownDict(const fvMesh& mesh);

        //- Return neighbour region membrane dictionary
        virtual dictionary nbrDict(const fvMesh& mesh, const word& patchName);

        //- Return neighbour patch name
        virtual word nbrPatchName(const fvMesh& mesh, const word& patchName);
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
