/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "constant.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace permeanceModels
{

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

defineTypeNameAndDebug(constant, 0);
addToRunTimeSelectionTable(permeanceModel, constant, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

constant::constant
(
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const word& patchName,
    const word& modelName
)
:
    permeanceModel(modelName, mesh, chemistry, patchName),
    mesh_(mesh),
    chemistry_(chemistry)
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

volScalarField constant::permeance
(
    const word& specie,
    const word& patchName,
    const word& nbrPatchName
)
{   
    scalar STPpermeance = readScalar(subDicts(patchDicts(), specie), "permeance");

    volScalarField permeance_
    (
        IOobject
        (
            "permeance",
            mesh_
        ),
        mesh_,
        dimensionedScalar("permeance", dimensionSet(-1, 2, 1, 0, 0, 0, 0), STPpermeance)
    );

    return permeance_;
}


bool constant::read()
{
    return true;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace permeanceModels
} // End namespace Foam

// ************************************************************************* //
