/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "multivariate.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace permeanceModels
{

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

defineTypeNameAndDebug(multivariate, 0);
addToRunTimeSelectionTable(permeanceModel, multivariate, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

multivariate::multivariate
(
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const word& patchName,
    const word& modelName
)
:
    permeanceModel(modelName, mesh, chemistry, patchName),
    mesh_(mesh),
    chemistry_(chemistry)
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

volScalarField multivariate::permeance
(
    const word& specie,
    const word& patchName,
    const word& nbrPatchName
)
{   
    Polynomial<8> tempCoeffs = readPolynom(subDicts(patchDicts(), specie), "tempCoeffs");
    Polynomial<8> massFracCoeffs = readPolynom(subDicts(patchDicts(), specie), "massFracCoeffs");
    Polynomial<8> pressCoeffs = readPolynom(subDicts(patchDicts(), specie), "pressCoeffs");

    volScalarField permeance_
    (
        IOobject
        (
            "permeance",
            mesh_
        ),
        mesh_,
        dimensionedScalar("permeance", dimensionSet(-1, 2, 1, 0, 0, 0, 0), 0.0)
    );

    const label patchID(mesh_.boundary().findPatchID(patchName));

    forAll(permeance_.boundaryFieldRef()[patchID], facei)
    {
        permeance_.boundaryFieldRef()[patchID][facei] 
      = 
        tempCoeffs.value(chemistry_.thermo().T().boundaryField()[patchID][facei])
      + massFracCoeffs.value(chemistry_.thermo().composition().Y(specie).boundaryField()[patchID][facei])
      + pressCoeffs.value(chemistry_.thermo().p().boundaryField()[patchID][facei]);
    }

    return permeance_;
}


bool multivariate::read()
{
    return true;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace permeanceModels
} // End namespace Foam

// ************************************************************************* //
