/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::permeanceModels::multivariate

Description
    Returns permeance based on multiple parameter variable

    References:
    \verbatim

    \endverbatim

    Sample dictionary:
    \verbatim
        CO2
        {
            tempCoeffs<8>       (5.91e-10 0 0 0 0 0 0 0);
            pressCoeffs<8>      (0 0 0 0 0 0 0 0);
            massFracCoeffs<8>   (0 0 0 0 0 0 0 0);
            refTemp             273.15;
            refPress            1.013e5;
        }
    \endverbatim

SourceFiles
    multivariate.C

\*---------------------------------------------------------------------------*/

#ifndef arrhenius_H
#define arrhenius_H

#include "permeanceModel.H"
#include "Polynomial.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace permeanceModels
{

/*---------------------------------------------------------------------------*\
                           Class multivariate Declaration
\*---------------------------------------------------------------------------*/

class multivariate
:
    public permeanceModel
{

protected:

    const fvMesh& mesh_;
    const combustionModels::rhoCombustionModel& chemistry_;

    
public:

    //- Runtime type information
    TypeName("multivariate");

    // Constructors

        //- Construct from components
        multivariate
        (
            const fvMesh& mesh,
            const combustionModels::rhoCombustionModel& chemistry,
            const word& patchName,
            const word& modelName = typeName
        );


    //- Destructor
    virtual ~multivariate()
    {}


    // Member Functions

        //- Return the permeance per specie 
        virtual volScalarField permeance
        (
            const word& specie,
            const word& patchName,
            const word& nbrPatchName
        );

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace permeanceModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
