/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "permeanceModel.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

defineTypeNameAndDebug(permeanceModel, 0);
defineRunTimeSelectionTable(permeanceModel, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

permeanceModel::permeanceModel
(
    const word& type,
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const word patchName
)
:
    membraneIO(mesh, patchName),
    mesh_(mesh),
    chemistry_(chemistry)
{}


// * * * * * * * * * * * * * * * * * Selectors * * * * * * * * * * * * * * * //

autoPtr<permeanceModel> permeanceModel::New
(
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const word patchName
)
{

    permeanceModel permeance("type", mesh, chemistry, patchName);

    word modelType 
        = permeance.readWord(permeance.patchDicts(), "permeanceModel");

    Info << "Selecting permeance model " << modelType << nl << endl;

    subModelConstructorTable::iterator cstrIter =
        subModelConstructorTablePtr_->find(modelType);

    if (cstrIter == subModelConstructorTablePtr_->end())
    {
        FatalErrorInFunction
            << "Unknown permeance model type "
            << modelType << nl << nl
            << "Valid permeance model types:" << endl
            << subModelConstructorTablePtr_->sortedToc()
            << exit(FatalError);
    }

    return autoPtr<permeanceModel>
    (
        cstrIter()(mesh, chemistry, patchName)
    );
}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //


volScalarField permeanceModel::permeance
(
    const word& specie,
    const word& patchName,
    const word& nbrPatchName
)
{
    return this->permeance(specie, patchName, nbrPatchName);
}


bool permeanceModel::read()
{
    return true;
}


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// ************************************************************************* //
