/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Namespace
    Foam::permeanceModels

Description
    Base class for calculating species permeances

Class
    Foam::permeanceModel

SourceFiles
    permeanceModel.C

\*---------------------------------------------------------------------------*/

#ifndef permeanceModel_H
#define permeanceModel_H

#include "IOdictionary.H"
#include "typeInfo.H"
#include "volFields.H"
#include "dimensionedScalar.H"
#include "Pair.H"
#include "nearWallDist.H"
#include "autoPtr.H"
#include "runTimeSelectionTables.H"
#include "fvCFD.H"
#include "rhoCombustionModel.H"
#include "mappedPatchBase.H"
#include "membraneIO.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

class membraneIO;

/*---------------------------------------------------------------------------*\
                           Class permeanceModel Declaration
\*---------------------------------------------------------------------------*/

class permeanceModel
:
    public membraneIO
{

protected:

    // Protected data
    const fvMesh& mesh_;
    const combustionModels::rhoCombustionModel& chemistry_;


private:

    // Private Member Functions

        //- Disallow default bitwise copy construct
        permeanceModel(const permeanceModel&);

        //- Disallow default bitwise assignment
        void operator=(const permeanceModel&);


public:

    //- Runtime type information
    TypeName("permeanceModel");


    // Declare run-time constructor selection table

        declareRunTimeSelectionTable
        (
            autoPtr,
            permeanceModel,
            subModel,
            (
                const fvMesh& mesh,
                const combustionModels::rhoCombustionModel& chemistry,
                const word patchName
            ),
            (mesh, chemistry, patchName)
        );


    // Constructors

        //- Construct from components
        permeanceModel
        (
            const word& type,
            const fvMesh& mesh,
            const combustionModels::rhoCombustionModel& chemistry,
            const word patchName
        );


    // Selectors

        //- Return a reference to the selected permeance model
        static autoPtr<permeanceModel> New
        (
            const fvMesh& mesh,
            const combustionModels::rhoCombustionModel& chemistry,
            const word patchName
        );


    //- Destructor
    virtual ~permeanceModel()
    {}


    // Member Functions

        //- Return the permeance per specie 
        virtual volScalarField permeance
        (
            const word& specie,
            const word& patchName,
            const word& nbrPatchName
        );

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
