/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "antoine.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace saturationPressureModels
{

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

defineTypeNameAndDebug(antoine, 0);
addToRunTimeSelectionTable(saturationPressureModel, antoine, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

antoine::antoine
(
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const word& modelName
)
:
    saturationPressureModel(modelName, mesh, chemistry),
    mesh_(mesh),
    chemistry_(chemistry)
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

volScalarField antoine::saturationPressure(const word& specie)
{
    dictionary thermoDict_
    (
        IFstream
        (
            fileName(chemistry_.thermo().lookup("foamChemistryThermoFile")).expand()
        )()
    );

    scalar A_
    (
        readScalar
        (
            thermoDict_.subDict(specie)
            .subDict("saturationPressure").lookup("A")
        )
    );

    scalar B_
    (
        readScalar
        (
            thermoDict_.subDict(specie)
            .subDict("saturationPressure").lookup("B")
        )
    );

    scalar C_
    (
        readScalar
        (
            thermoDict_.subDict(specie)
            .subDict("saturationPressure").lookup("C")
        )
    );
    
    volScalarField satPressField_
    (
        IOobject
        (
            "satPress",
            mesh_
        ),
        mesh_,
        dimensionedScalar("satPress", dimPressure, 0.0)
    );

    forAll(satPressField_, celli)
    {
        satPressField_[celli] 
       = 
        pow(10.0, A_ - B_ / (C_ + chemistry_.thermo().T()[celli]));
    }

    forAll(satPressField_.boundaryField(), patchi)
    {
        forAll(satPressField_.boundaryFieldRef()[patchi], facei)
        {
            satPressField_.boundaryFieldRef()[patchi][facei] 
           = 
            pow(10.0, A_ - B_ / (C_ + chemistry_.thermo().T().boundaryField()[patchi][facei]));
        }
    }

    return satPressField_;
}


bool antoine::read()
{
    return true;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace saturationPressureModels
} // End namespace Foam

// ************************************************************************* //
