/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "none.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace saturationPressureModels
{

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

defineTypeNameAndDebug(none, 0);
addToRunTimeSelectionTable(saturationPressureModel, none, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

none::none
(
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const word& modelName
)
:
    saturationPressureModel(modelName, mesh, chemistry),
    mesh_(mesh),
    chemistry_(chemistry)
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

volScalarField none::saturationPressure(const word& specie)
{   
    volScalarField satPressField_
    (
        IOobject
        (
            "satPress",
            mesh_
        ),
        mesh_,
        dimensionedScalar("satPress", dimPressure, 0.0)
    );

    label specieLabel(-1);

    forAll(chemistry_.thermo().composition().Y(), i)
    {
        if(chemistry_.thermo().composition().Y()[i].name() == specie)
            specieLabel = i;
    }

    satPressField_ = chemistry_.thermo().p() 
                   * chemistry_.thermo().composition().Y()[specieLabel];

    return satPressField_;
}


bool none::read()
{
    return true;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace saturationPressureModels
} // End namespace Foam

// ************************************************************************* //
