/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "polynomial.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace saturationPressureModels
{

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

defineTypeNameAndDebug(polynomial, 0);
addToRunTimeSelectionTable(saturationPressureModel, polynomial, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

polynomial::polynomial
(
    const fvMesh& mesh,
    const combustionModels::rhoCombustionModel& chemistry,
    const word& modelName
)
:
    saturationPressureModel(modelName, mesh, chemistry),
    mesh_(mesh),
    chemistry_(chemistry)
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

volScalarField polynomial::saturationPressure(const word& specie)
{
    dictionary thermoDict_
    (
        IFstream
        (
            fileName(chemistry_.thermo().lookup("foamChemistryThermoFile")).expand()
        )()
    );

    Polynomial<8> massFractionCoeffs_
    (
        thermoDict_.subDict(specie)
        .subDict("saturationPressure").lookup("massFractionCoeffs<" + Foam::name(8) + '>')
    );
    
    volScalarField satPressField_
    (
        IOobject
        (
            "satPress",
            mesh_
        ),
        mesh_,
        dimensionedScalar("satPress", dimPressure, 0.0)
    );

    const basicSpecieMixture& specieComposition = chemistry_.thermo().composition();
    const volScalarField& Yi = specieComposition.Y(specie);

    forAll(satPressField_, celli)
    {
        satPressField_[celli] 
       = 
        massFractionCoeffs_.value(Yi[celli]);
    }

    forAll(satPressField_.boundaryField(), patchi)
    {
        forAll(satPressField_.boundaryFieldRef()[patchi], facei)
        {
            satPressField_.boundaryFieldRef()[patchi][facei] 
           = 
            massFractionCoeffs_.value(Yi.boundaryField()[patchi][facei]);
        }
    }

    return satPressField_;
}


bool polynomial::read()
{
    return true;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace saturationPressureModels
} // End namespace Foam

// ************************************************************************* //
