/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Namespace
    Foam::saturationPressureModels

Description
    Base class for calculating saturation pressure

Class
    Foam::saturationPressureModel

SourceFiles
    saturationPressureModel.C

\*---------------------------------------------------------------------------*/

#ifndef saturationPressureModel_H
#define saturationPressureModel_H

#include "IOdictionary.H"
#include "typeInfo.H"
#include "volFields.H"
#include "dimensionedScalar.H"
#include "Pair.H"
#include "nearWallDist.H"
#include "autoPtr.H"
#include "runTimeSelectionTables.H"
#include "fvCFD.H"
#include "rhoCombustionModel.H"
#include "mappedPatchBase.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class saturationPressureModel Declaration
\*---------------------------------------------------------------------------*/

class saturationPressureModel
{

protected:

    // Protected data
    const fvMesh& mesh_;
    const combustionModels::rhoCombustionModel& chemistry_;


private:

    // Private Member Functions

        //- Disallow default bitwise copy construct
        saturationPressureModel(const saturationPressureModel&);

        //- Disallow default bitwise assignment
        void operator=(const saturationPressureModel&);


public:

    //- Runtime type information
    TypeName("saturationPressureModel");


    // Declare run-time constructor selection table

        declareRunTimeSelectionTable
        (
            autoPtr,
            saturationPressureModel,
            subModel,
            (
                const fvMesh& mesh,
                const combustionModels::rhoCombustionModel& chemistry
            ),
            (mesh, chemistry)
        );


    // Constructors

        //- Construct from components
        saturationPressureModel
        (
            const word& type,
            const fvMesh& mesh,
            const combustionModels::rhoCombustionModel& chemistry
        );


    // Selectors

        //- Return a reference to the selected saturation pressure model
        static autoPtr<saturationPressureModel> New
        (
            const fvMesh& mesh,
            const combustionModels::rhoCombustionModel& chemistry
        );

        //- Return a reference to the selected saturation pressure model without info printing
        static autoPtr<saturationPressureModel> runTimeNew
        (
            const fvMesh& mesh,
            const combustionModels::rhoCombustionModel& chemistry
        );


    //- Destructor
    virtual ~saturationPressureModel()
    {}


    // Member Functions

        //- Return the saturation pressure per specie 
        virtual volScalarField saturationPressure(const word& specie) = 0;

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
